Creates a valid function to be passed down to lua.
Note this function will not be registered automatically for you, you must use luaL_register or functions like lua_pushcfunction.
This may change in the future or allow for something like #[lua_function(name = “foo”, auto = true)]